#ifndef __GWEATHER_ABOUT_H_
#define __GWEATHER_ABOUT_H_

/* $Id: gweather-about.h,v 1.3.2.1 2002/07/10 23:48:58 mmclouglin Exp $ */

/*
 *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
 *
 *  This code released under the GNU GPL.
 *  Read the file COPYING for more information.
 *
 *  About box
 *
 */

#include "gweather.h"

G_BEGIN_DECLS

extern void gweather_about_run (GWeatherApplet *gw_applet);

G_END_DECLS

#endif /* __GWEATHER_ABOUT_H_ */

